==> apache-seatunnel-2.3.2-src.tar.gz: apache-seatunnel-2.3.2-src/seatunnel-engine/seatunnel-engine-server/src/main/java/org/apache/seatunnel/engine/server/SeaTunnelServerStarter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.engine.server;

import org.apache.seatunnel.engine.common.config.ConfigProvider;
import org.apache.seatunnel.engine.common.config.SeaTunnelConfig;

import com.hazelcast.instance.impl.HazelcastInstanceFactory;
import com.hazelcast.instance.impl.HazelcastInstanceImpl;
import com.hazelcast.instance.impl.HazelcastInstanceProxy;
import lombok.NonNull;

public class SeaTunnelServerStarter {

    public static void main(String[] args) {
        createHazelcastInstance();
    }

    public static HazelcastInstanceImpl createHazelcastInstance(String clusterName) {
        SeaTunnelConfig seaTunnelConfig = ConfigProvider.locateAndGetSeaTunnelConfig();
        seaTunnelConfig.getHazelcastConfig().setClusterName(clusterName);
        return createHazelcastInstance(seaTunnelConfig);
    }

    public static HazelcastInstanceImpl createHazelcastInstance(
            @NonNull SeaTunnelConfig seaTunnelConfig) {
        return ((HazelcastInstanceProxy)
                        HazelcastInstanceFactory.newHazelcastInstance(
                                seaTunnelConfig.getHazelcastConfig(),
                                HazelcastInstanceFactory.createInstanceName(
                                        seaTunnelConfig.getHazelcastConfig()),
                                new SeaTunnelNodeContext(seaTunnelConfig)))
                .getOriginal();
    }

    public static HazelcastInstanceImpl createHazelcastInstance() {
        SeaTunnelConfig seaTunnelConfig = ConfigProvider.locateAndGetSeaTunnelConfig();
        return createHazelcastInstance(seaTunnelConfig);
    }
}

==> apache-seatunnel-2.3.7-src.tar.gz: apache-seatunnel-2.3.7-src/seatunnel-engine/seatunnel-engine-server/src/main/java/org/apache/seatunnel/engine/server/SeaTunnelServerStarter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.engine.server;

import org.apache.seatunnel.engine.common.config.ConfigProvider;
import org.apache.seatunnel.engine.common.config.EngineConfig;
import org.apache.seatunnel.engine.common.config.SeaTunnelConfig;

import com.hazelcast.instance.impl.HazelcastInstanceFactory;
import com.hazelcast.instance.impl.HazelcastInstanceImpl;
import com.hazelcast.instance.impl.HazelcastInstanceProxy;
import lombok.NonNull;

public class SeaTunnelServerStarter {

    public static void main(String[] args) {
        createHazelcastInstance();
    }

    public static HazelcastInstanceImpl createHazelcastInstance(String clusterName) {
        SeaTunnelConfig seaTunnelConfig = ConfigProvider.locateAndGetSeaTunnelConfig();
        seaTunnelConfig.getHazelcastConfig().setClusterName(clusterName);
        return createHazelcastInstance(seaTunnelConfig);
    }

    public static HazelcastInstanceImpl createHazelcastInstance(
            @NonNull SeaTunnelConfig seaTunnelConfig) {
        return ((HazelcastInstanceProxy)
                        HazelcastInstanceFactory.newHazelcastInstance(
                                seaTunnelConfig.getHazelcastConfig(),
                                HazelcastInstanceFactory.createInstanceName(
                                        seaTunnelConfig.getHazelcastConfig()),
                                new SeaTunnelNodeContext(seaTunnelConfig)))
                .getOriginal();
    }

    public static HazelcastInstanceImpl createMasterAndWorkerHazelcastInstance(
            @NonNull SeaTunnelConfig seaTunnelConfig) {
        seaTunnelConfig
                .getEngineConfig()
                .setClusterRole(EngineConfig.ClusterRole.MASTER_AND_WORKER);
        return ((HazelcastInstanceProxy)
                        HazelcastInstanceFactory.newHazelcastInstance(
                                seaTunnelConfig.getHazelcastConfig(),
                                HazelcastInstanceFactory.createInstanceName(
                                        seaTunnelConfig.getHazelcastConfig()),
                                new SeaTunnelNodeContext(seaTunnelConfig)))
                .getOriginal();
    }

    public static HazelcastInstanceImpl createMasterHazelcastInstance(
            @NonNull SeaTunnelConfig seaTunnelConfig) {
        seaTunnelConfig.getEngineConfig().setClusterRole(EngineConfig.ClusterRole.MASTER);
        return ((HazelcastInstanceProxy)
                        HazelcastInstanceFactory.newHazelcastInstance(
                                seaTunnelConfig.getHazelcastConfig(),
                                HazelcastInstanceFactory.createInstanceName(
                                        seaTunnelConfig.getHazelcastConfig()),
                                new SeaTunnelNodeContext(seaTunnelConfig)))
                .getOriginal();
    }

    public static HazelcastInstanceImpl createWorkerHazelcastInstance(
            @NonNull SeaTunnelConfig seaTunnelConfig) {
        seaTunnelConfig.getEngineConfig().setClusterRole(EngineConfig.ClusterRole.WORKER);
        // in hazelcast lite node will not store IMap data.
        seaTunnelConfig.getHazelcastConfig().setLiteMember(true);
        return ((HazelcastInstanceProxy)
                        HazelcastInstanceFactory.newHazelcastInstance(
                                seaTunnelConfig.getHazelcastConfig(),
                                HazelcastInstanceFactory.createInstanceName(
                                        seaTunnelConfig.getHazelcastConfig()),
                                new SeaTunnelNodeContext(seaTunnelConfig)))
                .getOriginal();
    }

    public static HazelcastInstanceImpl createHazelcastInstance() {
        SeaTunnelConfig seaTunnelConfig = ConfigProvider.locateAndGetSeaTunnelConfig();
        return createHazelcastInstance(seaTunnelConfig);
    }
}
